package org.deken.game.animation;

import java.awt.Image;

/**
 * <p>Title: AnimatedFrame</p>
 *
 * <p>Description: The AnimatedFrame is a single image and it's duration time,
 * that can be used with the Animation interface, to create an animation strip.</p>
 * <p>The image itself can be any class that extends the Image class, such as the
 * BufferedImage and VolatileImage</p>
 *
 * <p>Copyright: Copyright (c) 2005</p>
 *
 * <p>@author Gary Deken: Based David Brackeen (Developing Games in Java)</p>
 * @version 1.0
 */
public class AnimatedFrame implements Cloneable {
  private Image image;
  private long endTime;

  /**
   * AnimatedFrame
   *
   * <p>The constructor takes an Image and the end time (or duration) of this
   * animated frame.</p>
   *
   * @param image Image
   * @param endTime long
   */
  public AnimatedFrame(Image image, long endTime) {
      this.image = image;
      this.endTime = endTime;
  }

  /**
   * getImage
   *
   * <p>This returns the image of this AnimatedFrame.</p>
   *
   * @return Image
   */
  public Image getImage() {
    return image;
  }

  /**
   * getEndTime
   *
   * <p>This is the duration of this frame, in milliseconds. It can be the time
   * since the begining of the animation strip, or just the length of this
   * image's duration.</p>
   *
   * @return long
   */
  public long getEndTime() {
    return endTime;
  }

  /**
   * clone
   * Creates a copy of this object.
   *
   * @return Object
   */
  public Object clone() {
    AnimatedFrame newFrame = new AnimatedFrame(this.image, this.endTime);

    return newFrame;
  }
}
