package org.deken.game.animation;

import java.awt.Color;
import java.awt.Image;
import org.deken.game.graphics.GameGFX;

/**
 * <p>Title: Circle Shape Animation</p>
 *
 * <p>Description: Draws a circle image to the GameGFX.</p>
 *
 * <p>Copyright: Copyright (c) Dec 29, 2010</p>
 *
 * @author Gary Deken<
 * @version 1.0
 */
public class CircleShapeAnimation implements Animation {
   private int height;
   private int width;
   private int xOffset = 0;
   private int yOffset = 0;
   private Color color;
   private String name;
   private boolean fill = false;

   /**
    * 
    * @param height
    * @param width
    * @param color
    * @param fill
    */
   public CircleShapeAnimation(int height, int width, Color color, boolean fill) {
      this.height = height;
      this.width = width;
      this.color = color;
      this.fill = fill;
   }

   /**
    * This animation has no frames. This method does nothing.
    * @param image
    * @param duration
    */
   public void addFrame(Image image, long duration) {
      //
   }

   /**
    * This animation has nothing to reset.
    */
   public void reset() {
      //
   }

   /**
    * This animation has nothing to update.
    * @param elapseTime
    */
   public void update(long elapseTime) {
      //
   }

   /**
    * This animation has no image to return.
    * @return null
    */
   public Image getImage() {
      return null;
   }

   /**
    * 
    * @param x
    * @param y
    */
   public void draw(int x, int y) {
      GameGFX.gfx().setColor(color);
      int xL = x + xOffset;
      int yL = y + yOffset;
      if (fill) {
         GameGFX.gfx().fillOval(xL, yL, width, height);
      }
      else {
         GameGFX.gfx().drawOval(xL, yL, width, height);
      }
   }

   /**
    * This animation as no Frame to return.
    * @param i
    * @return null
    */
   public Image getFrame(int i) {
      return null;
   }

   /**
    * 
    * @return height
    */
   public int getHeight() {
      return height;
   }

   /**
    * 
    * @return width
    */
   public int getWidth() {
      return width;
   }

   /**
    * Set the image offset.
    * @param x
    * @param y
    */
   public void setOffsets(int x, int y) {
      this.xOffset = x;
      this.yOffset = y;
   }

   /**
    * This animation is always in the same state.
    * @return true
    */
   public boolean isAnimating() {
      return true;
   }

   /**
    * 
    * @param name
    */
   public void setName(String name) {
      this.name = name;
   }

   /**
    * Copy Animation
    * @return CircleShapeAnimation
    */
   @Override
   public Object clone() {
      CircleShapeAnimation newAnimation = new CircleShapeAnimation(this.height, this.width, this.color, this.fill);

      newAnimation.setName(this.name);
      newAnimation.setOffsets(this.xOffset, this.yOffset);

      return newAnimation;
   }
}
