package org.deken.game.animation;

import java.awt.Image;

import org.deken.game.graphics.GameGFX;
import org.deken.game.movement.GameVector;

/**
 * <p>Title: TileAnimationStrip</p>
 *
 * <p>Description: </p>
 *
 * <p>Copyright: Copyright (c) 2005</p>
 *
 * <p>@author Gary Deken</p>
 * @version 1.0
 */
public class TileAnimationStrip implements Animation {
   private boolean animating;
   private GameVector vector = new GameVector(0, 1);
   private int height;
   private int width;
   private int xOffset = 0;
   private int yOffset = 0;
   private String name;

   /**
    * Used by clone().
    */
   protected TileAnimationStrip() {
   }

   /**
    * Animation Strip
    *
    * @param image
    * @param duration
    */
   public void addFrame(Image image, long duration) {
      if (height == 0 && width == 0) {
         height = image.getHeight(null);
         width = image.getWidth(null);
      }
   }

   /**
    * equals
    *
    * <p>Determines if two animation strips are the same, based on size of image
    * and number of frames.</p>
    *
    * @param obj Object
    * @return boolean
    */
   public boolean equals(Object obj) {
      if (obj instanceof TileAnimationStrip) {
         TileAnimationStrip test = (TileAnimationStrip) obj;
         if (height == test.height && width == test.width) {
            return true;
         }
      }
      return false;
   }

   public void reset() {
   }

   public void update(long elapseTime) {
   }

   public Image getImage() {
      return null;
   }

   /**
    * Draw
    * Draws the current frame index to the GameGFX, including any animation offsets.
    * @param x
    * @param y
    */
   public void draw(int x, int y) {
      int xL = x + xOffset;
      int yL = y + yOffset;
   //GameGFX.gfx().drawImage(image, xL, yL, null);
   }

   public Image getFrame(int i) {
      return null;
   }

   /**
    * setDirection
    *
    * <p>Set the direction the tile moves.</p>
    *
    * @param direction float
    */
   public void setDirection(float direction) {
      vector.setDirection(direction);
   }

   /**
    * getDirection
    *
    * <p>Returns the direction the tile is moving.</p>
    *
    * @return float
    */
   public float getDirection() {
      return vector.getDirection();
   }

   /**
    * getHeight
    *
    * <p>Returns the height of this animation strip.</p>
    *
    * @return int
    */
   public int getHeight() {
      return height;
   }

   /**
    * getWidth
    *
    * <p>Returns the width of this animation strip.</p>
    *
    * @return int
    */
   public int getWidth() {
      return width;
   }

   /**
    * setOffests
    * @param x
    * @param y
    */
   public void setOffsets(int x, int y) {
      xOffset = x;
      yOffset = y;
   }

   public boolean isAnimating() {
      return true;
   }

   /**
    * setName
    * Name is used for debugging.
    *
    * @param name String
    */
   public void setName(String name) {
      this.name = name;
   }

   /**
    * Copy Animation
    * @return TileAnimationStrip
    */
   public Object clone() {
      TileAnimationStrip newStrip = new TileAnimationStrip();

      newStrip.animating = this.animating;
      newStrip.vector = (GameVector) this.vector.clone();
      newStrip.height = this.height;
      newStrip.width = this.width;
      newStrip.name = this.name;

      return newStrip;
   }
}
